@@ -8,14 +8,10 @@ use overload
  '""'     => \&asString,
  fallback => 1;
 
-$VERSION = '0.10';
+$VERSION = '0.11';
 @EXPORT_OK   = qw(AUTOLOAD);
 %EXPORT_TAGS = ( 'standard' => [qw(AUTOLOAD)] );
 
-sub asdf {
-  return "foobar";
-}
-
 sub new {
   my $class = shift;
   my $self = bless {}, $class;
@@ -30,6 +26,8 @@ sub AUTOLOAD {
   return $req->new(@_);
 }
 
+sub DESTROY {}
+
 sub _init {
   my $self = shift;
   return 1;
